@@ -2,8 +2,8 @@
 Program's aim is to get tables from a given html
 Pure functional.
 """
-from BeautifulSoup import BeautifulSoup
-import urlparse
+import urllib.parse
+from bs4 import BeautifulSoup
 
 def _get_soup(html, elem):
     """
@@ -121,7 +121,7 @@ def _fix_url(soup, base_url):
     for a in aa:
         try:
             a_href_rel = a['href']
-            a_href = urlparse.urljoin(base_url, a_href_rel)
+            a_href = urllib.parse.urljoin(base_url, a_href_rel)
         except Exception as e:
             continue
     return a_href
@@ -131,7 +131,7 @@ if __name__ == "__main__":
     base_url = "http://www.jreda.com/tenders/tenders.htm"
     r = requests.get(base_url)
     num, tables = get_table_with_links(r.content, base_url)
-    print num
+    print(num)
     for table in tables:
         for link in table["links"]:
             print(link)
\ No newline at end of file
